################ Script CA fatty acids ################

# This is a script accompanying the manuscript
# "Responses of macroalgae to CO2 enrichment cannot be inferred solely from their inorganic carbon uptake strategy"
# Published in Ecology & Evolution


##### load and organise data #####
library(xlsx)
library(ggplot2)
library(vegan)
library(MASS)

d <- read.table("Data_CAFA.txt", header=T)


# extra information dataframe
env <- read.table("DATA_CA_FA_env.txt", header=T)
levels(env$treatment)


##### Correspondence analysis #####
# the function cca() perfoms the correspondence analysis:

ca <- cca(d)
ca
summary(ca)
plot(ca, scaling=1)

# calculate how much of the variation each axis explains:
# this is the total inertia (variance):
chisq.test(d/sum(d))
# axis 1 = eigenvalue CA1/total inertia: 
0.14619/0.1597*100 # explains 98.2%
# axis 2 = eigenvalue CA2/total intertia:
0.00395/0.1597*100 # explains 0.8%


##### Plot CA #####
colvec <- c("orange","firebrick4", "steelblue1","green3") # select colors
levels <- c("Ambient CCM","Ambient non-CCM","Future CCM","Future non-CCM") # names in legend
symbol <- c(21,21,21,21) #17, 21
cex <- c(1.2,1.2,1.2,1.2)
scl <- 1

pl <- ordipointlabel(ca, 
                     display="sites",
                     scaling=scl, xlim=c(-2,2), ylim=c(-1.5,1.5),
                     xlab="CA axis 1 (98.2% variation explained)",
                     ylab="CA axis 2 (0.8% variation explained)")
pl <- with(ca, points(ca, display = "sites", col = colvec[env$treatment],
                      scaling = scl, pch = symbol[env$treatment], cex=cex[env$treatment], bg = colvec[env$treatment])) # this adds the colours
pl >- with(ca, legend("topright", legend = levels, bty = "n",
                      col = colvec, pch = symbol, pt.bg = colvec)) # adds legend


##### contribution plot ######

library(FactoMineR)
library(factoextra)
library("corrplot")

# Contribution plot of each fatty acid
# (i.e. how much does each of the fatty acids controbitue to the pattern observed in the CA plot)
res.ca <- CA(d, graph = FALSE)
summary(res.ca, nb.dec = 2, ncp = 2)
fviz_contrib(res.ca, choice = "col", axes = 1:2)

# And visualised in a balloonplot:
corrplot(col$contrib, is.corr=FALSE)

################ End of script ################
