################ Script P/E curves ################

# This is a script accompanying the manuscript
# "Responses of macroalgae to CO2 enrichment cannot be inferred solely from their inorganic carbon uptake strategy"
# Published in Ecology & Evolution


# load data
library(ggplot2)
library(plyr)
library(reshape2)

d <- read.table("Data_PAM.txt",header=T)
str(d)

# First, make subsets of both species:
CCM <- subset(d, Species=="CCM")
nonCCM <- subset(d, Species=="non-CCM")


####### Fit curves based on Webb et al. 1974 ############
library(phytotools)

# The CCM species:
myfit <- fitWebb(CCM$PAR, CCM$ETR, normalize = FALSE, lowerlim = c(0, 1), upperlim = c(100, 1000),
                 fitmethod=c("Nelder-Mead"))
myfit # This gives the alpha and Ek value for the CCM species

# create predicted values:
E <- seq(0,371,by=1)
pred <- myfit$alpha[1]*myfit$ek[1]*(1-exp(-E/myfit$ek[1]))
pred.frameCCM <- melt(pred, id="date", value.name="ETR") 
pred.frameCCM["PAR"] <- E

# The non-CCM species:
myfit <- fitWebb(nonCCM$PAR, nonCCM$ETR, normalize = FALSE, lowerlim = c(0, 1), upperlim = c(100, 1000),
                 fitmethod=c("Nelder-Mead"))
myfit # This gives the alpha and Ek value for the non-CCM species

# create predicted values
E <- seq(0,371,by=1)
pred <- myfit$alpha[1]*myfit$ek[1]*(1-exp(-E/myfit$ek[1]))
pred.framenonCCM <- melt(pred, id="date", value.name="ETR") 
pred.framenonCCM["PAR"] <- E

# Plot the datapoints and the predicted values (shown as a curve)
ggplot(NULL, aes(x=PAR, y=ETR))+
  geom_point(data = CCM,col="steelblue3") +
  geom_point(data = nonCCM,col="orange3")+
  geom_line(data=pred.frameCCM,lwd=1.2,col="royalblue4")+
  geom_line(data=pred.framenonCCM,lwd=1.2,col="orange2")+
  labs(x="PAR (umol photons m-2 s-1)",y="ETR")+
  theme_bw()+
  scale_y_continuous(expand = c(0, 0), limits = c(0, 8),breaks=c(0,2,4,6,8))+
  scale_x_continuous(expand = c(0, 0), limits = c(0, 400),breaks=c(0,100,200,300,400))

################ End of script ################